@@ -115,8 +115,8 @@ class ConfigEnum(StrEnum):
             self.kcp_enable: {'category': ConfigCategory.kcp,'type':bool,'apply_mode':'apply'},
             self.decoy_domain: {'category': ConfigCategory.general,'apply_mode':'apply'},
             self.proxy_path: {'category': ConfigCategory.general,'apply_mode':'apply','show_in_parent':True},
-            self.firewall: {'category': ConfigCategory.general,'apply_mode':'apply'},
-            self.netdata: {'category': ConfigCategory.general,'apply_mode':'apply'},
+            self.firewall: {'category': ConfigCategory.general,'type':bool,'apply_mode':'apply'},
+            self.netdata: {'category': ConfigCategory.general,'type':bool,'apply_mode':'apply'},
             self.http_proxy_enable: {'category': ConfigCategory.http,'type':bool},
             self.block_iran_sites: {'category': ConfigCategory.proxies,'type':bool,'apply_mode':'apply'},
             self.allow_invalid_sni: {'category': ConfigCategory.tls,'type':bool,'apply_mode':'apply'},
