@@ -5,7 +5,7 @@ from hiddifypanel.panel.database import db
 from hiddifypanel.panel.init_db import init_db
 from hiddifypanel.models import *
 
-from hiddifypanel.panel import hiddify
+from hiddifypanel.panel import hiddify,usage
 import random
 import uuid
 import urllib
@@ -40,7 +40,7 @@ def all_configs():
     print(json.dumps(configs))
 
 def update_usage():
-    print(hiddify.update_usage())
+    print(usage.update_local_usage())
 
 def test():
     print(ConfigEnum("auto_update1"))
